@@ -13,6 +13,7 @@ import shutil
 import tempfile
 import platform
 import json
+import warnings
 
 import luigi
 
@@ -275,6 +276,19 @@ class QueenbeeTask(luigi.Task):
             pass
         logger.info(f'Finished running {self.__class__.__name__}...')
 
+    @staticmethod
+    def load_input_param(input_param):
+        """A static class kept here for backwards compatability.
+
+        Use the `load_input_param` function directly instead.
+        """
+        warnings.warn(
+            'load_input_param classmethod is deprecated. Update your code to use the '
+            'function directly instead.',
+            category=DeprecationWarning, stacklevel=2
+        )
+        return load_input_param(input_param)
+
 
 def load_input_param(input_param):
     """This function tries to import the values from a file as a Task input
