@@ -2,6 +2,7 @@
 import os
 import json
 import shutil
+import pathlib
 
 from typing import Union, Dict, List
 from distutils.dir_util import copy_tree
@@ -90,17 +91,19 @@ def _change_permission(dst):
 
 def _copy_artifacts(src, dst):
     """copy file or folder."""
-    if os.path.normpath(src) == os.path.normpath(dst):
+    src = pathlib.Path(src).resolve()
+    dst = pathlib.Path(dst).resolve()
+
+    if src.as_posix() == dst.as_posix():
         # input and output files are the same file
         return
     try:
         # try to copy the folder
-        copy_tree(src, dst)
-        _change_permission(dst)
+        copy_tree(src.as_posix(), dst.as_posix())
+        _change_permission(dst.as_posix())
     except DistutilsFileError:
+        # it is a file - try to copy the file
         # create the folder if doesn't exist
-        dirname = os.path.dirname(dst)
-        if not os.path.isdir(dirname):
-            os.makedirs(dirname)
-        shutil.copy(src, dst)
-        _change_permission(dirname)
+        dst.parent.mkdir(exist_ok=True, parents=True)
+        shutil.copy(src.as_posix(), dst.as_posix())
+        _change_permission(dst.parent.as_posix())
